Paul Vriens : advpack: Add another test.

Alexandre Julliard julliard at wine.codeweavers.com
Tue Oct 31 15:07:59 CST 2006


Module: wine
Branch: master
Commit: 26172f8aa41d86644aa6a30a4d33cd190c614785
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=26172f8aa41d86644aa6a30a4d33cd190c614785

Author: Paul Vriens <paul.vriens.wine at gmail.com>
Date:   Tue Oct 31 18:36:50 2006 +0100

advpack: Add another test.

---

 dlls/advpack/tests/install.c |    8 +++++++-
 1 files changed, 7 insertions(+), 1 deletions(-)

diff --git a/dlls/advpack/tests/install.c b/dlls/advpack/tests/install.c
index f589a0d..96c09a3 100644
--- a/dlls/advpack/tests/install.c
+++ b/dlls/advpack/tests/install.c
@@ -233,13 +233,19 @@ static void test_LaunchINFSectionEx()
 
     create_inf_file("test.inf");
 
     /* try an invalid CAB filename */
     lstrcpy(cmdline, CURR_DIR);
     lstrcat(cmdline, "\\");
     lstrcat(cmdline, "test.inf,DefaultInstall,c:imacab.cab,4");
     hr = pLaunchINFSectionEx(NULL, NULL, cmdline, 0);
     ok(hr == 0, "Expected 0, got %d\n", hr);
 
+    /* try an invalid CAB filename with a relative INF name */
+    lstrcpy(cmdline, "test.inf,DefaultInstall,c:imacab.cab,4");
+    hr = pLaunchINFSectionEx(NULL, NULL, cmdline, 0);
+    todo_wine
+        ok(hr == E_INVALIDARG, "Expected E_INVALIDARG, got %d\n", hr);
+
     DeleteFileA("test.inf");
 }
 
@@ -233,13 +233,19 @@ static void test_LaunchINFSectionEx()
     create_inf_file("test.inf");
 
-    /* try an invalid CAB filename */
+    /* try an invalid CAB filename with an absolute INF name */
     lstrcpy(cmdline, CURR_DIR);
     lstrcat(cmdline, "\\");




More information about the wine-cvs mailing list